@@ -4,10 +4,10 @@
 // *** インストール後 *** にGeeklog本家配布分のDBデータを日本語に
 // ローカライズする・英語に戻すクラス
 //
-//       対象：Geeklog-1.5.0
+//       対象：Geeklog-1.8.0
 //       作者：mystral-kk - geeklog AT mystral-kk DOT net
 // ライセンス：GPL
-// バージョン：2008-08-24
+// バージョン：2011-06-15
 //     使用法：このファイルをrequire_onceしたのち、
 //               $obj = new LocalizeGeeklog;
 //               // 日本語化するとき
@@ -18,31 +18,40 @@
 
 global $_CONF, $_TABLES;
 
+/**
+* Loads config, because $_CONF is not set fully at this point of installation
+*/
+require_once '../../siteconfig.php';
+require_once $_CONF['path_system'] . 'classes/config.class.php';
+
+$temp_config = config::get_instance();
+$temp_config->set_configfile($_CONF['path'] . 'db-config.php');
+$temp_config->load_baseconfig();
+$temp_config->initConfig();
+$_CONF = $temp_config->get_config('Core');
+
 class LocalizeGeeklog
 {
 	/**
 	* ローカライズモード
 	* 現在は 'en', 'ja' のみ。
-	*
-	* @access private
 	*/
-	var $_mode;
-	var $_supported_modes = array(
+	private $_mode;
+	private $_supported_modes = array(
 		'ja' => '日本語',
 		'en' => 'English',
 	);
 
-	function LocalizeGeeklog($mode = 'ja')
+	public function __construct($mode = 'ja')
 	{
 		$this->setMode($mode);
 	}
 	
 	/**
 	* ローカライズモードをセット
-	*
-	* @access public
 	*/
-	function setMode($mode) {
+	public function setMode($mode)
+	{
 		$mode = strtolower($mode);
 		
 		if (!in_array($mode, array_keys($this->_supported_modes))) {
@@ -53,30 +62,24 @@ class LocalizeGeeklog
 	
 	/**
 	* ローカライズモードを返す
-	*
-	* @access public
 	*/
-	function getMode()
+	public function getMode()
 	{
 		return $this->_mode;
 	}
 	
 	/**
 	* サポートされているモードを返す
-	*
-	* @access public
 	*/
-	function getSupportedModes()
+	public function getSupportedModes()
 	{
 		return $this->_supported_modes;
 	}
 	
 	/**
 	* ローカライズ用のデータ配列をセット
-	*
-	* @access public
 	*/
-	function setData($data)
+	public function setData($data)
 	{
 		if (is_array($data) AND (count($data) > 0)) {
 			$this->_data = $data;
@@ -85,24 +88,21 @@ class LocalizeGeeklog
 	
 	/**
 	* ローカライズ用のデータ配列を取得
-	*
-	* @access public
 	*/
-	function getData()
+	public function getData()
 	{
 		return $this->_data;
 	}
 	
 	/**
 	* ローカライズ実行
-	*
-	* @access public
 	*/
-	function execute($mode = '')
+	public function execute($mode = '')
 	{
 		if (!in_array($mode, array_keys($this->_supported_modes))) {
-			$this->setMode('ja');
+			$mode = 'ja';
 		}
+		$this->setMode($mode);
 		
 		$this->_changeMain();
 		$this->_changeLinks();
@@ -111,30 +111,46 @@ class LocalizeGeeklog
 		$this->_changeUsers();
 		$this->_changeMisc();
 		$this->_changeConfig();
+		$this->_changeTheme();
+	}
+	
+	/**
+	* GDライブラリがインストールされているかチェック
+	*
+	* @return boolean  TRUE = installed, FALSE = otherwise
+	*/
+	public function isGDInstalled()
+	{
+		if (is_callable('gd_info') OR is_callable('imagegd')
+		 OR is_callable('imagegd2')) {
+			return TRUE;
+		} else {
+			return FALSE;
+		}
 	}
 	
 	/**
 	* 更新メイン
-	*
-	* @access protected
 	*/
-	function _changeMain()
+	protected function _changeMain()
 	{
 		global $_TABLES;
 		
 		foreach ($this->_data as $table => $rows) {
-			foreach ($rows as $R) {
-				$sql = "UPDATE " . $_TABLES[$table] . " "
-					 . "SET " . $R['target'] . " = '"
-					 . addslashes($R[$this->_mode]) . "' "
-					 . "WHERE (" . $R['field'] . " = '" . addslashes($R['value'])
-					 . "')";
-				if (isset($R['field2']) AND isset($R['value2'])) {
-					$sql .= " AND (" . $R['field2'] . " = '"
-						 .  addslashes($R['value2']) . "')";
+			if (DB_checkTableExists($table)) {
+				foreach ($rows as $R) {
+					$sql = "UPDATE " . $_TABLES[$table] . " "
+						 . "SET " . $R['target'] . " = '"
+						 . addslashes($R[$this->_mode]) . "' "
+						 . "WHERE (" . $R['field'] . " = '" . addslashes($R['value'])
+						 . "')";
+					if (isset($R['field2']) AND isset($R['value2'])) {
+						$sql .= " AND (" . $R['field2'] . " = '"
+							 .  addslashes($R['value2']) . "')";
+					}
+					
+					DB_query($sql);
 				}
-				
-				DB_query($sql);
 			}
 		}
 	}
@@ -143,17 +159,23 @@ class LocalizeGeeklog
 	/**
 	* リンク
 	*
-	* 日本語化するときにGeeklog.jpを追加、戻すときにGeeklog.jpを削除
-	*
-	* @access protected
+	* 1. Geeklog Sitesの説明
+	* 2. 日本語化するときにGeeklog.jpを追加、戻すときにGeeklog.jpを削除
 	*/
-	function _changeLinks()
+	protected function _changeLinks()
 	{
 		global $_TABLES;
 		
+		if (!DB_checkTableExists('links')) {
+			return;
+		}
+		
 		$sqls = array();
 		
-		if ($this->_mode == 'ja') {
+		if ($this->_mode === 'ja') {
+			$sqls[] = "UPDATE {$_TABLES['linkcategories']} "
+					. "SET description = '" . addslashes('Geeklog関係のサイト') . "' "
+					. "WHERE (cid = '" . addslashes('geeklog-sites') . "')";
 			if (DB_count($_TABLES['links'], 'lid', 'geeklog.jp') == 0) {
 				$sqls[] = "INSERT INTO {$_TABLES['links']} "
 					 	. "(lid, cid, url, description, title, hits, date, "
@@ -165,7 +187,11 @@ class LocalizeGeeklog
 						. addslashes('Geeklog Japanese') . "', 0, NOW(), 1, 5, "
 						. "3, 3, 2, 2);";
 			}
-		} else if ($this->_mode == 'en') {
+		} else if ($this->_mode === 'en') {
+			$sqls[] = "UPDATE {$_TABLES['linkcategories']} "
+					. "SET description = '"
+					. addslashes('Sites using or related to the Geeklog CMS') . "' "
+					. "WHERE (cid = '" . addslashes('geeklog-sites') . "')";
 			$sqls[] = "DELETE FROM {$_TABLES['links']} "
 					. "WHERE (lid = 'geeklog.jp')";
 		}
@@ -180,17 +206,19 @@ class LocalizeGeeklog
 	/**
 	* 更新ピング
 	*
-	* 日本語化するときにサイト追加、戻すときに削除
-	*
-	* @access protected
+	* 日本語化するときのサイト = (BlogPeople, ping.bloggers.jp, ドリコムRSS,
+								  gooブログ, Googleブログ検索, テクノラティ)
+	* 英語に戻すときのサイト   = (Ping-O-Matic)
 	*/
-	function _changePingServices()
+	protected function _changePingServices()
 	{
 		global $_TABLES;
 		
 		$sqls = array();
 		
-		if ($this->_mode == 'ja') {
+		if ($this->_mode === 'ja') {
+			$sqls[] = "DELETE FROM {$_TABLES['pingservice']} "
+					. "WHERE (name = 'Ping-O-Matic')";
 			if (DB_count($_TABLES['pingservice'], 'name', 'BlogPeople') == 0) {
 				$sqls[] = "INSERT INTO {$_TABLES['pingservice']} (pid, name, "
 						. "site_url, ping_url, method, is_enabled) VALUES "
@@ -212,17 +240,32 @@ class LocalizeGeeklog
 						. "'http://ping.rss.drecom.jp/', "
 						. "'weblogUpdates.ping', 1)";
 			}
-			if (DB_count($_TABLES['pingservice'], 'name', 'Technorati Japan') == 0) {
+			if (DB_count($_TABLES['pingservice'], 'name', 'gooブログ') == 0) {
 				$sqls[] = "INSERT INTO {$_TABLES['pingservice']} (pid, name, "
 						. "site_url, ping_url, method, is_enabled) VALUES "
-						. "(0, 'Technorati Japan', 'http://technorati.jp/', "
-						. "'http://rpc.technorati.jp/rpc/ping', "
+						. "(0, 'gooブログ', 'http://blog.goo.ne.jp/', "
+						. "'http://blog.goo.ne.jp/XMLRPC', "
 						. "'weblogUpdates.ping', 1)";
 			}
-		} else if ($this->_mode == 'en') {
+			if (DB_count($_TABLES['pingservice'], 'name', 'Googleブログ検索') == 0) {
+				$sqls[] = "INSERT INTO {$_TABLES['pingservice']} (pid, name, "
+						. "site_url, ping_url, method, is_enabled) VALUES "
+						. "(0, 'Googleブログ検索', 'http://blogsearch.google.co.jp/', "
+						. "'http://blogsearch.google.co.jp/ping/RPC2', "
+						. "'weblogUpdates.extendedPing', 1)";
+			}
+		} else if ($this->_mode === 'en') {
+			if (DB_count($_TABLES['pingservice'], 'name', 'Ping-O-Matic') == 0) {
+				$sqls[] = "INSERT INTO {$_TABLES['pingservice']} (pid, name, "
+						. "site_url, ping_url, method, is_enabled) VALUES "
+						. "(0, 'Ping-O-Matic', 'http://pingomatic.com/', "
+						. "'http://rpc.pingomatic.com/', "
+						. "'weblogUpdates.ping', 1)";
+			}
+			
 			$sqls[] = "DELETE FROM {$_TABLES['pingservice']} "
 					. "WHERE (name IN ('BlogPeople', 'ping.bloggers.jp', "
-					. "'" . addslashes('ドリコムRSS') . "', 'Technorati Japan'))";
+					. "'ドリコムRSS', 'gooブログ', 'Googleブログ検索'))";
 		}
 		
 		if (count($sqls) > 0) {
@@ -234,29 +277,27 @@ class LocalizeGeeklog
 	
 	/**
 	* 記事
-	*
-	* @access protected
 	*/
-	function _changeStories()
+	protected function _changeStories()
 	{
 		global $_CONF, $_TABLES;
 		
 		$sqls = array();
 		
-		if ($this->_mode == 'en') {
+		if ($this->_mode === 'en') {
 			$sqls[] = "UPDATE {$_TABLES['stories']} "
 					. "SET title = 'Welcome to Geeklog!', "
-					. "introtext = '" . addslashes("<p>Welcome and let me be the first to congratulate you on installing Geeklog. Please take the time to read everything in the <a href=\"docs/index.html\">docs directory</a>. Geeklog now has enhanced, user-based security.  You should thoroughly understand how these work before you run a production Geeklog Site.</p>\n<p>To log into your new Geeklog site, please use this account:</p>\n<p>Username: <b>Admin</b><br />\nPassword: <b>password</b></p><p><b>And don't forget to <a href=\"{$_CONF['site_url']}/usersettings.php?mode=edit\">change your password</a> after logging in!</b></p>")
+					. "introtext = '" . addslashes("<p>Welcome and let me be the first to congratulate you on installing Geeklog. Please take the time to read everything in the <a href=\"docs/english/index.html\">docs directory</a>. Geeklog now has enhanced, user-based security.  You should thoroughly understand how these work before you run a production Geeklog Site.</p>\n<p>To log into your new Geeklog site, please use this account:</p>\n<p>Username: <b>Admin</b><br />\nPassword: <b>password</b></p><p><b>And don't forget to <a href=\"{$_CONF['site_url']}/usersettings.php?mode=edit\">change your password</a> after logging in!</b></p>")
 					. "' "
 					. "WHERE (sid = 'welcome')";
 			$sqls[] = "UPDATE {$_TABLES['storysubmission']} "
 					. "SET title = 'Are you secure?', "
 					. "introtext = '" . addslashes("<p>This is a reminder to secure your site once you have Geeklog up and running. What you should do:</p>\n\n<ol>\n<li>Change the default password for the Admin account.</li>\n<li>Remove the install directory (you won\'t need it any more).</li>\n</ol>") . "' "
 					. "WHERE (sid = 'security-reminder')";
-		} else if ($this->_mode == 'ja') {
+		} else if ($this->_mode === 'ja') {
 			$sqls[] = "UPDATE {$_TABLES['stories']} "
 					. "SET title = '" . addslashes('Geeklogへようこそ!') . "', "
-					. "introtext = '" . addslashes("<p>無事インストールが完了したようですね。おめでとうございます。できれば、<a href=\"docs/index.html\">docs ディレクトリ</a>のすべての文書に一通り目を通しておいてください。Geeklogはユーザを中心としたセキュリティモデルを実装しています。Geeklogを管理・運用するにはこの仕組みを理解する必要があります。</p>\n<p>サイトにログインするには、次のアカウントを使用してください:</p>\n<p>ユーザ名: <strong>Admin</strong><br />\nパスワード: <strong>password</strong></p><p><strong>ログインしたら、忘れずに<a href=\"{$_CONF['site_url']}/usersettings.php?mode=edit\">パスワードを変更</a>してください。</strong></p><p>Geeklogのサポートは、<a href=\"http://www.geeklog.jp\">Geeklog Japanese</a>へ。追加ドキュメントは <a href=\"http://wiki.geeklog.jp\">Geeklog Wiki ドキュメント</a>をどうぞ。</p>")
+					. "introtext = '" . addslashes("<p>無事インストールが完了したようですね。おめでとうございます。できれば、<a href=\"docs/japanese/index.html\">docs ディレクトリ</a>のすべての文書に一通り目を通しておいてください。Geeklogはユーザーを中心としたセキュリティモデルを実装しています。Geeklogを管理・運用するにはこの仕組みを理解する必要があります。</p>\n<p>サイトにログインするには、次のアカウントを使用してください:</p>\n<p>ユーザー名: <strong>Admin</strong><br />\nパスワード: <strong>password</strong></p><p><strong>ログインしたら、忘れずに<a href=\"{$_CONF['site_url']}/usersettings.php?mode=edit\">パスワードを変更</a>してください。</strong></p><p>Geeklogのサポートは、<a href=\"http://www.geeklog.jp\">Geeklog Japanese</a>へ。追加ドキュメントは <a href=\"http://wiki.geeklog.jp\">Geeklog Wiki ドキュメント</a>をどうぞ。</p>")
 					. "' "
 					. "WHERE (sid = 'welcome')";
 			$sqls[] = "UPDATE {$_TABLES['storysubmission']} "
@@ -272,17 +313,15 @@ class LocalizeGeeklog
 	}
 	
 	/**
-	* ユーザ定義＆データ
-	*
-	* @access protected
+	* ユーザー定義＆データ
 	*/
-	function _changeUsers()
+	protected function _changeUsers()
 	{
 		global $_TABLES;
 		
 		$sqls = array();
 		
-		if ($this->_mode == 'en') {
+		if ($this->_mode === 'en') {
 			$sqls[] = "ALTER TABLE {$_TABLES['users']} "
 					. "MODIFY username VARCHAR(16) ";
 			$sqls[] = "UPDATE {$_TABLES['users']} "
@@ -291,14 +330,14 @@ class LocalizeGeeklog
 			$sqls[] = "UPDATE {$_TABLES['users']} "
 					. "SET fullname= 'Geeklog SuperUser', homepage='http://www.geeklog.net/' "
 					. "WHERE (uid = 2)";
-		} else if ($this->_mode == 'ja'){
+		} else if ($this->_mode === 'ja'){
 			$sqls[] = "ALTER TABLE {$_TABLES['users']} "
 					. "MODIFY username VARCHAR(108) ";
 			$sqls[] = "UPDATE {$_TABLES['users']} "
-					. "SET username = 'ゲストユーザ', fullname= 'ゲストユーザ' "
+					. "SET username = 'ゲストユーザー', fullname= 'ゲストユーザー' "
 					. "WHERE (uid = 1)";
 			$sqls[] = "UPDATE {$_TABLES['users']} "
-					. "SET fullname= 'サイト管理者', homepage='http://www.example.come/' "
+					. "SET fullname= 'サイト管理者', homepage='' "
 					. "WHERE (uid = 2)";
 		}
 		
@@ -309,37 +348,42 @@ class LocalizeGeeklog
 	
 	/**
 	* その他
-	*
-	* @access protected
 	*/
-	function _changeMisc()
+	protected function _changeMisc()
 	{
 		global $_TABLES;
 		
 		$sqls = array();
 		
-		if ($this->_mode == 'en') {
+		if ($this->_mode === 'en') {
 			$sqls[] = "ALTER TABLE {$_TABLES['syndication']} "
 					. "ALTER language SET DEFAULT 'en-gb'";
 			$sqls[] = "ALTER TABLE {$_TABLES['users']} "
 					. "MODIFY username VARCHAR(16)";
-			$sqls[] = "ALTER TABLE {$_TABLES['events']} "
-					. "MODIFY zipcode VARCHAR(5)";
-			$sqls[] = "ALTER TABLE {$_TABLES['eventsubmission']} "
-					. "MODIFY zipcode VARCHAR(5)";
-
-		} else if ($this->_mode == 'ja') {
+			if (DB_checkTableExists('events')) {
+				$sqls[] = "ALTER TABLE {$_TABLES['events']} "
+						. "MODIFY zipcode VARCHAR(5)";
+				$sqls[] = "ALTER TABLE {$_TABLES['eventsubmission']} "
+						. "MODIFY zipcode VARCHAR(5)";
+				$sqls[] = "ALTER TABLE {$_TABLES['personal_events']} "
+						. "MODIFY zipcode VARCHAR(5)";
+			}
+		} else if ($this->_mode === 'ja') {
 			// シンジケーションの言語の初期値
 			$sqls[] = "ALTER TABLE {$_TABLES['syndication']} "
 					. "ALTER language SET DEFAULT 'ja'";
-			// ユーザ名を108バイト（全角36文字くらい）に
+			// ユーザー名を108バイト（全角36文字くらい）に
 			$sqls[] = "ALTER TABLE {$_TABLES['users']} "
 					. "MODIFY username VARCHAR(108)";
-			// イベントの郵便番号を8桁に
-			$sqls[] = "ALTER TABLE {$_TABLES['events']} "
-					. "MODIFY zipcode VARCHAR(8)";
-			$sqls[] = "ALTER TABLE {$_TABLES['eventsubmission']} "
-					. "MODIFY zipcode VARCHAR(8)";
+			if (DB_checkTableExists('events')) {
+				// イベントの郵便番号を8桁に
+				$sqls[] = "ALTER TABLE {$_TABLES['events']} "
+						. "MODIFY zipcode VARCHAR(8)";
+				$sqls[] = "ALTER TABLE {$_TABLES['eventsubmission']} "
+						. "MODIFY zipcode VARCHAR(8)";
+				$sqls[] = "ALTER TABLE {$_TABLES['personal_events']} "
+						. "MODIFY zipcode VARCHAR(8)";
+			}
 		}
 		
 		foreach ($sqls as $sql) {
@@ -349,17 +393,15 @@ class LocalizeGeeklog
 	
 	/**
 	* コンフィギュレーション
-	*
-	* @access protected
 	*/
-	function _changeConfig()
+	protected function _changeConfig()
 	{
 		global $_CONF, $_TABLES;
 		
 		require_once $_CONF['path_system'] . 'classes/config.class.php';
 		$c = config::get_instance();
 		
-		if ($this->_mode == 'en') {
+		if ($this->_mode === 'en') {
 			// サイト一時閉鎖メッセージ
 			$c->set('site_disabled_msg', 'Geeklog Site is down. Please come back soon.');
 			
@@ -396,20 +438,20 @@ class LocalizeGeeklog
 			$c->set(
 				'user_html',
 				array(
-					'p'      => array(),
-					'b'      => array(),
-					'strong' => array(),
-					'i'      => array(),
 					'a'      => array('href' => 1, 'title' => 1, 'rel' => 1),
-					'em'     => array(),
+					'b'      => array(),
 					'br'     => array(),
-					'tt'     => array(),
+					'code'   => array(),
+					'em'     => array(),
 					'hr'     => array(),
+					'i'      => array(),
 					'li'     => array(),
 					'ol'     => array(),
-					'ul'     => array(),
-					'code'   => array(),
+					'p'      => array(),
 					'pre'    => array(),
+					'strong' => array(),
+					'tt'     => array(),
+					'ul'     => array(),
 				)
 			);
 			$c->set(
@@ -454,10 +496,19 @@ class LocalizeGeeklog
 			);
 			$c->set('hour_mode', 12, 'calendar');
 			
+			// 画像関係
+			$c->set('keep_unscaled_image', 0);	// 元画像を残す = FALSE
+			$c->set('image_lib', '', 'Core');
 			
-		} else if ($this->_mode == 'ja') {
+			// 記事関係
+			$c->set('advanced_editor', FALSE);
+			
+			// 管理者関係
+			$c->set('sort_admin', TRUE);
+			
+		} else if ($this->_mode === 'ja') {
 			// サイト一時閉鎖メッセージ
-			$c->set('site_disabled_msg', 'サイトメンテナンス中');
+			$c->set('site_disabled_msg', $_CONF['site_url'] . '/disabledmsg.html');
 			
 			// 言語＆多言語
 			$c->set_default('rdf_language','ja');	// 'ja-JP'の方がよいかも
@@ -480,26 +531,27 @@ class LocalizeGeeklog
 # 			);
 			
 			// ロケール
-			if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
+			if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
 				$c->set('locale', 'C');
-				$c->set('date', '%Y年%b月%d日(%a) %H:%M');
-				$c->set('daytime', '%b %d %H:%M');
-				$c->set('shortdate', '%x');
-				$c->set('dateonly', '%b %d');
+				$c->set('date', '%Y年%m月%d日 %H:%M');
+				$c->set('daytime', '%m月%d日 %H:%M');
+				$c->set('shortdate', '%d');
+				$c->set('dateonly', '%m/%d');
+				$c->set('timeonly', '%H:%M');
 			} else {
-				if (strtoupper(substr(PHP_OS, 0, 7)) == 'FREEBSD') {
+				if (strtoupper(substr(PHP_OS, 0, 7)) === 'FREEBSD') {
 					$c->set('locale', 'ja_JP');
 				} else {
 					$c->set('locale', 'ja_JP.UTF-8');
 				}
-				$c->set('date', '%Y年%B%e日(%a) %H:%M (%Z)');
-				$c->set('daytime', '%B%e日 %H:%M');
-				$c->set('shortdate', '%x');
+				$c->set('date', '%Y年%B%e日(%a) %H:%M %Z');
+				$c->set('daytime', '%m/%d %H:%M %Z');
+				$c->set('shortdate', '%Y年%B%e日');
 				$c->set('dateonly', '%B%e日');
+				$c->set('timeonly', '%H:%M %Z');
 			}
 			
 			$c->set('rdf_language', 'ja');
-			$c->set('timeonly', '%H:%M');
 			$c->set('hour_mode', 24);
 			$c->set('timezone', 'Asia/Tokyo');
 			
@@ -507,66 +559,90 @@ class LocalizeGeeklog
 			$c->set(
 				'user_html',
 				array(
-					'p'      => array(),
-					'b'      => array(),
-					'strong' => array(),
-					'i'      => array(),
-					'a'      => array('href' => 1, 'title' => 1, 'rel' => 1),
-					'em'     => array(),
-					'br'     => array(),
-					'tt'     => array(),
-					'hr'     => array(),
-					'li'     => array(),
-					'ol'     => array(),
-					'ul'     => array(),
-					'code'   => array(),
-					'div'    => array('class' => 1, 'id' => 1),
-					'pre'    => array(),
+					'a'          => array('href' => 1, 'title' => 1, 'rel' => 1),
+					'b'          => array(),
+					'blockquote' => array(),
+					'br'         => array('clear' => 1),
+					'code'       => array(),
+					'div'        => array('class' => 1, 'id' => 1),
+					'em'         => array(),
+					'font'       => array('color' => 1),
+					'h'          => array(),
+					'hr'         => array(),
+					'i'          => array(),
+					'li'         => array(),
+					'ol'         => array(),
+					'p'          => array('lang' => 1),
+					'pre'        => array(),
+					'strong'     => array(),
+					'tt'         => array(),
+					'ul'         => array(),
 				)
 			);
 			$c->set(
 				'admin_html',
 				array (
-					'a'      => array(
-									'href' => 1, 'title' => 1, 'id' => 1,
-									'lang' => 1, 'name' => 1, 'type' => 1,
-									'rel' => 1
+					'a'        => array(
+									'href' => 1, 'title' => 1, 'id'   => 1,
+									'lang' => 1, 'name'  => 1, 'type' => 1,
+									'rel'  => 1
 								),
-					'p'      => array(
-									'class' => 1, 'id' => 1, 'align' => 1, 'style' => 1
+					'br'       => array('style' => 1),
+					'caption'  => array('style' => 1),
+					'div'      => array('style' => 1),
+					'embed'    => array(
+									'align'       => 1, 'height'  => 1, 'loop' => 1,
+									'pluginspage' => 1, 'quality' => 1, 'src'  => 1,
+									'type'        => 1, 'width'   => 1
 								),
-					'div'    => array('class' => 1, 'id' => 1, 'style' => 1),
-					'font'   => array('face' => 1, 'size' => 1, 'style' => 1),
-					'hr'     => array('style' => 1),
-					'img'    => array(
-									'src' => 1, 'width' => 1, 'height' => 1,
-									'vspace' => 1, 'hspace' => 1, 'dir' => 1,
-									'align' => 1, 'valign' => 1, 'border' => 1,
-									'lang' => 1, 'longdesc' => 1, 'title' => 1,
-									'id' => 1, 'alt' => 1, 'style' => 1
+					'h1'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'h2'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'h3'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'h4'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'h5'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'h6'       => array('class' => 1, 'id' => 1, 'style' => 1),
+					'hr'       => array('align' => 1, 'class' => 1, 'id' => 1),
+					'img'      => array(
+									'align'  => 1, 'alt'    => 1, 'border'   => 1,
+									'dir'    => 1, 'height' => 1, 'hspace'   => 1,
+									'id'     => 1, 'lang'   => 1, 'longdesc' => 1,
+									'src'    => 1, 'style'  => 1, 'title'    => 1,
+									'valign' => 1, 'vspace' => 1, 'width'    => 1
 								),
-					'ol'     => array('style' => 1),
-					'ul'     => array('style' => 1),
-					'span'   => array('class' => 1, 'id' => 1, 'style' => 1),
-					'table'  => array(
-									'class' => 1, 'id' => 1, 'width' => 1,
-									'border' => 1, 'cellspacing' => 1,
-									'cellpadding' => 1, 'style' => 1
+					'noscript' => array(),
+					'object'   => array(
+									'align' => 1, 'classid' => 1, 'codebase' => 1,
+									'data'  => 1, 'height'  => 1, 'type'     => 1,
+									'width' => 1
 								),
-					'caption' => array(),
-					'tr'     => array(
-									'class' => 1, 'id' => 1, 'align' => 1,
+					'ol'       => array('class' => 1, 'style' => 1),
+					'p'        => array(
+									'align' => 1, 'class' => 1, 'id' => 1
+								),
+					'param'    => array('name' => 1, 'value' => 1),
+					'script'   => array(
+									'language' => 1, 'src' => 1, 'type' => 1
+								),
+					'span'     => array('class' => 1, 'id' => 1, 'lang' => 1),
+					'table'    => array(
+									'border'      => 1, 'cellpadding' => 1,
+									'cellspacing' => 1, 'class'       => 1,
+									'id'          => 1, 'width'       => 1
+								),
+					'tbody'    => array(),
+					'td'       => array(
+									'align'  => 1, 'class'   => 1, 'colspan' => 1,
+									'id'     => 1, 'rowspan' => 1, 'valign'  => 1
+								),
+					'th'       => array(
+									'align'  => 1, 'class'   => 1, 'colspan' => 1,
+									'id'     => 1, 'rowspan' => 1, 'valign'  => 1
+								),
+					'tr'       => array(
+									'align'  => 1, 'class'   => 1, 'id'      => 1, 
 									'valign' => 1
 								),
-					'th'     => array(
-									'class' => 1, 'id' => 1, 'align' => 1,
-									'valign' => 1, 'colspan' => 1, 'rowspan' => 1
-								),
-					'td'     => array(
-									'class' => 1, 'id' => 1, 'align' => 1,
-									'valign' => 1, 'colspan' => 1, 'rowspan' => 1
-								),
-					'tbody'  => array(),
+					'ul'       => array('class' => 1, 'style' => 1),
 				)
 			);
 			
@@ -584,16 +660,54 @@ class LocalizeGeeklog
 				'calendar'
 			);
 			$c->set('hour_mode', 24, 'calendar');
+			
+			// 画像関係
+			$c->set('keep_unscaled_image', 1);	// 元画像を残す = TRUE
+			if ($this->isGDInstalled()) {
+				$c->set('image_lib', 'gdlib', 'Core');
+			}
+			
+			// 記事関係
+			$c->set('advanced_editor', TRUE);
+			
+			// 管理者関係
+			$c->set('sort_admin', FALSE);
+		}
+	}
+	
+	/**
+	* テーマ変更
+	*
+	* @note  Geeklog-1.8.0日本語版より従来のProfessionalCSSがprofessional_cssへ
+	*        と改称されたため、$_CONF['theme']がProfessionalCSSの場合、強制的に
+	*        変更する。
+	*/
+	protected function _changeTheme()
+	{
+		global $_CONF;
+		
+		if (defined('VERSION')
+		 AND (version_compare(VERSION, '1.8.0') >= 0)
+		 AND ($_CONF['theme'] === 'ProfessionalCSS')) {
+			clearstatcache();
+			
+			if (file_exists($_CONF['path_themes'] . 'professional_css')) {
+				$c = config::get_instance();
+				$c->set('theme', 'professional_css', 'Core');
+				
+				$sql = "UPDATE {$_TABLES['users']} "
+					 . "  SET theme = 'professional_css' "
+					 . "  WHERE theme = 'ProfessionalCSS' ";
+				DB_query($sql);
+			}
 		}
 	}
 	
 	//=====================================================
 	// ローカライズ用データ
-	//
-	// @access private
 	//=====================================================
 	
-	var $_data = array(
+	private $_data = array(
 		/**
 		* ブロックタイトル・内容
 		*/
@@ -603,7 +717,7 @@ class LocalizeGeeklog
 				'value'  => 'user_block',
 				'target' => 'title',
 				'en'     => 'User Functions',
-				'ja'     => 'ユーザ情報',
+				'ja'     => 'ユーザー情報',
 			),
 			array(
 				'field'  => 'name',
@@ -619,13 +733,13 @@ class LocalizeGeeklog
 				'en'     => 'Topics',
 				'ja'     => '記事カテゴリ',
 			),
-			array(
-				'field'  => 'name',
-				'value'  => 'polls_block',
-				'target' => 'title',
-				'en'     => 'Poll',
-				'ja'     => 'アンケート',
-			),
+# 			array(
+# 				'field'  => 'name',
+# 				'value'  => 'polls_block',
+# 				'target' => 'title',
+# 				'en'     => 'Poll',
+# 				'ja'     => 'アンケート',
+# 			),
 			array(
 				'field'  => 'name',
 				'value'  => 'events_block',
@@ -652,7 +766,7 @@ class LocalizeGeeklog
 				'value'  => 'whosonline_block',
 				'target' => 'title',
 				'en'     => 'Who\'s Online',
-				'ja'     => 'オンラインユーザ',
+				'ja'     => 'オンラインユーザー',
 			),
 			array(
 				'field'  => 'name',
@@ -666,7 +780,7 @@ class LocalizeGeeklog
 				'value'  => 'first_block',
 				'target' => 'content',
 				'en'     => '<p><b>Welcome to Geeklog!</b></p><p>If you\'re already familiar with Geeklog - and especially if you\'re not: There have been many improvements to Geeklog since earlier versions that you might want to read up on. Please read the <a href=\"docs/changes.html\">release notes</a>. If you need help, please see the <a href=\"docs/support.html\">support options</a>.</p>',
-				'ja'     => '<p><strong>Geeklogへようこそ!</strong><p>Geeklogのサポートは、<a href="http://www.geeklog.jp">Geeklog Japanese</a>へ。ドキュメントは <a href="http://wiki.geeklog.jp">Geeklog Wikiドキュメント</a>をどうぞ。',
+				'ja'     => '<p><strong>Geeklogへようこそ!</strong></p><p>Geeklogのサポートは、<a href="http://www.geeklog.jp">Geeklog Japanese</a>へ。ドキュメントは <a href="http://wiki.geeklog.jp">Geeklog Wikiドキュメント</a>をどうぞ。</p>',
 			),
 		),
 		
@@ -816,7 +930,7 @@ class LocalizeGeeklog
 				'value'  => '2006051410130162',
 				'target' => 'location',
 				'en'     => 'Your webserver',
-				'ja'     => 'Webサーバ',
+				'ja'     => 'Webサーバー',
 			),
 		),
 		
@@ -877,21 +991,21 @@ class LocalizeGeeklog
 				'value'  => 'user.edit',
 				'target' => 'ft_descr',
 				'en'     => 'Access to user editor',
-				'ja'     => 'ユーザを編集する権限',
+				'ja'     => 'ユーザーを編集する権限',
 			),
 			array(
 				'field'  => 'ft_name',
 				'value'  => 'user.delete',
 				'target' => 'ft_descr',
 				'en'     => 'Ability to delete a user',
-				'ja'     => 'ユーザを削除する権限',
+				'ja'     => 'ユーザーを削除する権限',
 			),
 			array(
 				'field'  => 'ft_name',
 				'value'  => 'user.mail',
 				'target' => 'ft_descr',
 				'en'     => 'Ability to send email to members',
-				'ja'     => 'メンバーにEメールを送信する権限',
+				'ja'     => 'メンバーにメールを送信する権限',
 			),
 			array(
 				'field'  => 'ft_name',
@@ -1064,7 +1178,7 @@ class LocalizeGeeklog
 				'value'  => 'All Users',
 				'target' => 'grp_descr',
 				'en'     => 'Group that a typical user is added to',
-				'ja'     => 'すべてのユーザ',
+				'ja'     => 'すべてのユーザー',
 			),
 			array(
 				'field'  => 'grp_name',
@@ -1113,7 +1227,7 @@ class LocalizeGeeklog
 				'value'  => 'User Admin',
 				'target' => 'grp_descr',
 				'en'     => 'Has full access to user features',
-				'ja'     => 'ユーザ管理者',
+				'ja'     => 'ユーザー管理者',
 			),
 			array(
 				'field'  => 'grp_name',
@@ -1127,7 +1241,7 @@ class LocalizeGeeklog
 				'value'  => 'Group Admin',
 				'target' => 'grp_descr',
 				'en'     => 'Is a User Admin with access to groups, too',
-				'ja'     => 'グループ管理者兼ユーザ管理者',
+				'ja'     => 'グループ管理者兼ユーザー管理者',
 			),
 			array(
 				'field'  => 'grp_name',
@@ -1141,7 +1255,7 @@ class LocalizeGeeklog
 				'value'  => 'Logged-in Users',
 				'target' => 'grp_descr',
 				'en'     => 'All registered members',
-				'ja'     => 'すべての登録ユーザ',
+				'ja'     => 'すべての登録ユーザー',
 			),
 			array(
 				'field'  => 'grp_name',
@@ -1162,7 +1276,7 @@ class LocalizeGeeklog
 				'value'  => 'Remote Users',
 				'target' => 'grp_descr',
 				'en'     => 'Users in this group can have authenticated against a remote server.',
-				'ja'     => 'リモート認証ユーザ',
+				'ja'     => 'リモート認証ユーザー',
 			),
 			array(
 				'field'  => 'grp_name',
@@ -1176,7 +1290,7 @@ class LocalizeGeeklog
 				'value'  => 'Webservices Users',
 				'target' => 'grp_descr',
 				'en'     => 'Can use the Webservices API (if restricted)',
-				'ja'     => 'WebサービスAPIユーザ',
+				'ja'     => 'WebサービスAPIユーザー',
 			),
 		),
 		
@@ -1216,135 +1330,135 @@ class LocalizeGeeklog
 		/**
 		* アンケートの選択肢
 		*/
-		'pollanswers' => array(
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 1,
-				'target' => 'answer',
-				'en'     => 'MS SQL support',
-				'ja'     => 'Microsoft SQLサーバのサポート',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 2,
-				'target' => 'answer',
-				'en'     => 'Multi-language support',
-				'ja'     => '多言語サポート',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 3,
-				'target' => 'answer',
-				'en'     => 'Calendar as a plugin',
-				'ja'     => 'カレンダのプラグイン化',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 4,
-				'target' => 'answer',
-				'en'     => 'SLV spam protection',
-				'ja'     => 'SLVによるスパム防御',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 5,
-				'target' => 'answer',
-				'en'     => 'Mass-delete users',
-				'ja'     => 'ユーザ一括削除',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'aid',
-				'value2' => 6,
-				'target' => 'answer',
-				'en'     => 'Other',
-				'ja'     => 'その他',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 1,
-				'field2' => 'aid',
-				'value2' => 1,
-				'target' => 'answer',
-				'en'     => 'Story-Images',
-				'ja'     => '記事で画像を扱える',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 1,
-				'field2' => 'aid',
-				'value2' => 2,
-				'target' => 'answer',
-				'en'     => 'User-Rights handling',
-				'ja'     => 'ユーザ権限管理',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 1,
-				'field2' => 'aid',
-				'value2' => 3,
-				'target' => 'answer',
-				'en'     => 'The Support',
-				'ja'     => 'サポート体制',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 1,
-				'field2' => 'aid',
-				'value2' => 4,
-				'target' => 'answer',
-				'en'     => 'Plugin Availability',
-				'ja'     => 'プラグイン',
-			),
-		),
+# 		'pollanswers' => array(
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 1,
+# 				'target' => 'answer',
+# 				'en'     => 'MS SQL support',
+# 				'ja'     => 'Microsoft SQLサーバーのサポート',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 2,
+# 				'target' => 'answer',
+# 				'en'     => 'Multi-language support',
+# 				'ja'     => '多言語サポート',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 3,
+# 				'target' => 'answer',
+# 				'en'     => 'Calendar as a plugin',
+# 				'ja'     => 'カレンダのプラグイン化',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 4,
+# 				'target' => 'answer',
+# 				'en'     => 'SLV spam protection',
+# 				'ja'     => 'SLVによるスパム防御',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 5,
+# 				'target' => 'answer',
+# 				'en'     => 'Mass-delete users',
+# 				'ja'     => 'ユーザー一括削除',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'aid',
+# 				'value2' => 6,
+# 				'target' => 'answer',
+# 				'en'     => 'Other',
+# 				'ja'     => 'その他',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 1,
+# 				'field2' => 'aid',
+# 				'value2' => 1,
+# 				'target' => 'answer',
+# 				'en'     => 'Story-Images',
+# 				'ja'     => '記事で画像を扱える',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 1,
+# 				'field2' => 'aid',
+# 				'value2' => 2,
+# 				'target' => 'answer',
+# 				'en'     => 'User-Rights handling',
+# 				'ja'     => 'ユーザー権限管理',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 1,
+# 				'field2' => 'aid',
+# 				'value2' => 3,
+# 				'target' => 'answer',
+# 				'en'     => 'The Support',
+# 				'ja'     => 'サポート体制',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 1,
+# 				'field2' => 'aid',
+# 				'value2' => 4,
+# 				'target' => 'answer',
+# 				'en'     => 'Plugin Availability',
+# 				'ja'     => 'プラグイン',
+# 			),
+# 		),
 		
 		/**
 		* アンケートの質問事項
 		*/
-		'pollquestions' => array(
-			array(
-				'field'  => 'qid',
-				'value'  => 0,
-				'field2' => 'pid',
-				'value2' => 'geeklogfeaturepoll',
-				'target' => 'question',
-				'en'     => 'What is the best new feature of Geeklog?',
-				'ja'     => 'Geeklogの新機能で一番良いものは?',
-			),
-			array(
-				'field'  => 'qid',
-				'value'  => 1,
-				'field2' => 'pid',
-				'value2' => 'geeklogfeaturepoll',
-				'target' => 'question',
-				'en'     => 'What is the all-time best feature of Geeklog?',
-				'ja'     => 'Geeklogの機能で今も変わらず一番良い機能は?',
-			),
-		),
-		
-		/**
-		* アンケートの話題
-		*/
-		'polltopics' => array(
-			array(
-				'field'  => 'pid',
-				'value'  => 'geeklogfeaturepoll',
-				'target' => 'topic',
-				'en'     => 'Tell us your opinion about Geeklog',
-				'ja'     => 'Geeklogについてお答えください。',
-			),
-		),
+# 		'pollquestions' => array(
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 0,
+# 				'field2' => 'pid',
+# 				'value2' => 'geeklogfeaturepoll',
+# 				'target' => 'question',
+# 				'en'     => 'What is the best new feature of Geeklog?',
+# 				'ja'     => 'Geeklogの新機能で一番良いものは?',
+# 			),
+# 			array(
+# 				'field'  => 'qid',
+# 				'value'  => 1,
+# 				'field2' => 'pid',
+# 				'value2' => 'geeklogfeaturepoll',
+# 				'target' => 'question',
+# 				'en'     => 'What is the all-time best feature of Geeklog?',
+# 				'ja'     => 'Geeklogの機能で今も変わらず一番良い機能は?',
+# 			),
+# 		),
+# 		
+# 		/**
+# 		* アンケートの話題
+# 		*/
+# 		'polltopics' => array(
+# 			array(
+# 				'field'  => 'pid',
+# 				'value'  => 'geeklogfeaturepoll',
+# 				'target' => 'topic',
+# 				'en'     => 'Tell us your opinion about Geeklog',
+# 				'ja'     => 'Geeklogについてお答えください。',
+# 			),
+# 		),
 		
 		/**
 		* 投稿モード
@@ -1442,7 +1556,7 @@ class LocalizeGeeklog
 				'value'  => 'General',
 				'target' => 'topic',
 				'en'     => 'General News',
-				'ja'     => '一般',
+				'ja'     => 'おしらせ',
 			),
 		),
 		
