@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.7                                                               |
 // +---------------------------------------------------------------------------+
 // | japanese_utf-8.php                                                        |
 // |                                                                           |
 // | Japanese language file for the Geeklog installation script                |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -51,9 +51,9 @@ $LANG_CHARSET = 'utf-8';
 // install.php
 
 $LANG_INSTALL = array(
-    0 => 'Geeklog - The Ultimate Weblog System',
+    0 => 'Geeklog - The secure CMS.',
     1 => 'インストールで困ったら、こちらのサイトへ',
-    2 => 'The Ultimate Weblog System',
+    2 => 'The secure CMS.',
     3 => 'Geeklogをインストールする',
     4 => 'PHP %s以上が必要です',
     5 => '残念ながらGeeklogをインストールするには最低でもPHP %sが必要です(現在のバージョンは ',
@@ -72,7 +72,7 @@ $LANG_INSTALL = array(
     18 => '記事に画像を添付する機能が無効になっています。<code>articles</code>ディレクトリのテストを行いませんでした。',
     19 => 'Geeklogでは、いくつかのファイルとディレクトリがWebサーバーから書き込める必要があります。以下は、変更する必要のあるファイルとディレクトリの一覧です。',
     20 => '警告!',
-    21 => '上記のエラーが解消されるまで、あなたのGeeklogサイトは正常に動作しないでしょう。先へ進む前に、必要な変更を行ってください。',
+    21 => '以下のエラーが解消されるまで、インストールできません。先に必要な変更を行ってください。',
     22 => '不明',
     23 => 'インストールの種類を選択してください:',
     24 => '新規インストール',
@@ -130,7 +130,7 @@ $LANG_INSTALL = array(
     76 => '現在のGeeklogのバージョンを選択してください',
     77 => 'インストーラは現在のGeeklogのバージョンを判定できませんでした。下のリストから選択してください:',
     78 => 'アップグレードエラー',
-    79 => 'Geeklogをアップグレード中にエラーが発生しました。',
+    79 => 'Geeklogのアップグレード中にエラーが発生しました。',
     80 => '変更',
     81 => 'ちょっと待って!',
     82 => '下に列挙されたファイルのパーミッションを必ず変更する必要があります。変更するまでGeeklogをインストールできません。',
@@ -150,13 +150,16 @@ $LANG_INSTALL = array(
     96 => 'インストーラはここで %s を探しています:',
     97 => 'パーミッション設定',
     98 => 'アドバンストユーザ',
-    99 => 'コマンドライン (SSH) が使えるなら、Webサーバーにアクアセスしてください。shellで、簡単に以下のコマンドのコピー・ペーストが可能です。:',
+    99 => 'コマンドライン (SSH) が使えるなら、Webサーバーにアクアセスしてください。shellを使えば、以下のコマンドのコピー・ペーストで簡単に実行できます。:',
     100 => '無効なモードを指定',
     101 => 'ステップ',
     102 => 'コンフィギュレーションモード入力',
     103 => '＋追加プラグインの設定',
     104 => '不正な管理者パス',
-    105 => '入力した管理者のディレクトリパスは不正確でした。もう一度やり直してください。'
+    105 => '入力した管理者のディレクトリパスは不正確でした。もう一度やり直してください。',
+    106 => 'PostgreSQL',
+    107 => 'データベースのパスワードが必要です。',
+    108 => 'データベースドライバーがありません!'
 );
 
 // +---------------------------------------------------------------------------+
@@ -177,7 +180,7 @@ $LANG_SUCCESS = array(
     11 => '次の',
     12 => 'つのことを忘れずに行ってください',
     13 => 'installディレクトリを削除またはリネームする:',
-    14 => '',
+    14 => '変更する',
     15 => 'アカウントのパスワードを変更する。',
     16 => 'パーミッションを設定する:',
     17 => 'と',
@@ -285,9 +288,7 @@ $LANG_BIGDUMP = array(
     8 => '作業中 ファイル:',
     9 => 'ファイルの末尾にファイルポインタを移動できません。',
     10 => 'ファイルポインタ移動不可:',
-    11 => '中止した行番号:',
-    12 => '。ここのカレントクエリはCSVファイルからですが、',
-    13 => 'はセットされませんでした。',
+    11 => 'There is no MySQL extension available in your PHP installation.',
     14 => '中止した行版:',
     15 => '。このクエリには',
     16 => '行以上が含まれています。各クエリの末尾にセミコロンを付けないツールでダンプファイルを生成した場合や、ダンプファイルの中に複数行INSERT文が含まれる場合に発生する可能性があります。',
@@ -302,7 +303,7 @@ $LANG_BIGDUMP = array(
     25 => ' ミリ秒</b> 次のセッションが始まるまで...',
     26 => 'インポート中止',
     27 => 'インポートの中止はこちら。',
-    28 => '',
+    28 => 'インポートが完了するまでしばらく待ってください!',
     29 => 'エラーが発生しました。',
     30 => '最初からスタート',
     31 => '(再起動する前に古いテーブルを削除してください)'
