@@ -245,7 +245,7 @@ function liststories($current_topic = '')
 function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
 {
     global $_CONF, $_TABLES, $_USER, $LANG24, $LANG_ACCESS, $LANG_ADMIN,
-           $MESSAGE;
+           $MESSAGE, $_SCRIPTS;
 
     $display = '';
 
@@ -317,9 +317,15 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     }
 
     // Load HTML templates
-    $story_templates = new Template($_CONF['path_layout'] . 'admin/story');
+    $story_templates = COM_newTemplate($_CONF['path_layout'] . 'admin/story');
     if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
-        $story_templates->set_file(array('editor'=>'storyeditor_advanced.thtml'));
+        $thtml = $_CONF['path_layout'] . 'admin/story/storyeditor_advanced.' . $_CONF['language'] . '.thtml';
+        if (file_exists($thtml)) {
+            $thtml = 'storyeditor_advanced.' . $_CONF['language'] . '.thtml';
+        } else {
+            $thtml = 'storyeditor_advanced.thtml';
+        }
+        $story_templates->set_file('editor', $thtml);
         $advanced_editormode = true;
         $story_templates->set_var ('change_editormode', 'onchange="change_editmode(this);"');
 
@@ -349,14 +355,10 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         } else {
             $thtml = 'storyeditor.thtml';
         }
-        $story_templates->set_file(array('editor' => $thtml));
+        $story_templates->set_file('editor', $thtml);
         $advanced_editormode = false;
     }
-    $story_templates->set_var('xhtml', XHTML);
-    $story_templates->set_var('site_url',       $_CONF['site_url']);
-    $story_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $story_templates->set_var('layout_url',     $_CONF['layout_url']);
-    $story_templates->set_var('hour_mode',      $_CONF['hour_mode']);
+     $story_templates->set_var('hour_mode',      $_CONF['hour_mode']);
 
     if ($story->hasContent()) {
         $previewContent = STORY_renderArticle($story, 'p');
@@ -527,7 +529,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     if ($story->EditElements('statuscode') == STORY_ARCHIVE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
         $story_templates->set_var('is_checked3', 'checked="checked"');
-        $story_templates->set_var('showarchivedisabled', 'false');
+        $js_showarchivedisabled = 'false';
         $have_archive_topic = true; // force display of auto archive option
     } elseif ($story->EditElements('statuscode') == STORY_DELETE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
@@ -535,12 +537,12 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         if (! $have_archive_topic) {
             $story_templates->set_var('is_checked3', 'style="display:none;"');
         }
-        $story_templates->set_var('showarchivedisabled', 'false');
+        $js_showarchivedisabled = 'false';
     } else {
         if (! $have_archive_topic) {
             $story_templates->set_var('is_checked3', 'style="display:none;"');
         }
-        $story_templates->set_var('showarchivedisabled', 'true');
+        $js_showarchivedisabled = 'true';
     }
     $story_templates->set_var('lang_archivetitle', $LANG24[58]);
     $story_templates->set_var('lang_option', $LANG24[59]);
@@ -603,9 +605,9 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('lang_cmt_disable', $LANG24[63]);
     if ($story->EditElements('cmt_close')) {
         $story_templates->set_var('is_checked5', 'checked="checked"');
-        $story_templates->set_var('showcmtclosedisabled', 'false');
+        $js_showcmtclosedisabled = 'false';
     } else {
-        $story_templates->set_var('showcmtclosedisabled', 'true');
+        $js_showcmtclosedisabled = 'true';
     }
 
     $month_options = COM_getMonthFormOptions($story->EditElements('cmt_close_month'));
@@ -678,8 +680,8 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('lang_bodytext', $LANG24[17]);
     $story_templates->set_var('lang_postmode', $LANG24[4]);
     $story_templates->set_var('lang_publishoptions',$LANG24[76]);
-    $story_templates->set_var('lang_nojavascript',$LANG24[77]);
-    $story_templates->set_var('no_javascript_return_link',sprintf($LANG24[78],$_CONF['site_admin_url'], $sid));
+    $story_templates->set_var('noscript', COM_getNoScript(false, $LANG24[77], sprintf($LANG24[78],$_CONF['site_admin_url'], $sid)));
+    
     $post_options = COM_optionList($_TABLES['postmodes'],'code,name',$story->EditElements('postmode'));
 
     // If Advanced Mode - add post option and set default if editing story created with Advanced Editor
@@ -732,6 +734,85 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         }
         $fileinputs .= $LANG24[28] . '<br' . XHTML . '>';
     }
+    
+    // *****************************************    
+    // Add JavaScript
+    if (!$advanced_editormode) {
+        $js = '<script type="text/javascript">
+        //<![CDATA[
+        function enablearchive(obj) {
+            var f = obj.form;           // all elements have their parent form in "form"
+            var disable = obj.checked;  // Disable when checked
+            if (f.elements["archiveflag"].checked==true && f.elements["storycode11"].checked==false) {
+                f.elements["storycode10"].checked=true;
+            }
+            f.elements["storycode10"].disabled=!disable;
+            f.elements["storycode11"].disabled=!disable;
+            f.elements["expire_month"].disabled=!disable;
+            f.elements["expire_day"].disabled=!disable;
+            f.elements["expire_year"].disabled=!disable;
+            f.elements["expire_hour"].disabled=!disable;
+            f.elements["expire_minute"].disabled=!disable;
+            f.elements["expire_ampm"].disabled=!disable;
+        }
+            
+            function enablecmtclose(obj) {
+            var f = obj.form;           // all elements have their parent form in "form"
+            var disable = obj.checked;  // Disable when checked
+        
+            f.elements["cmt_close_month"].disabled=!disable;
+            f.elements["cmt_close_day"].disabled=!disable;
+            f.elements["cmt_close_year"].disabled=!disable;
+            f.elements["cmt_close_hour"].disabled=!disable;
+            f.elements["cmt_close_minute"].disabled=!disable;
+            f.elements["cmt_close_ampm"].disabled=!disable;
+            
+        }
+        //]]>
+        </script>' . LB;
+    } else {
+        $js = '<script type="text/javascript">
+            // Setup editor path for FCKeditor JS Functions
+            geeklogEditorBasePath = "' . $_CONF['site_url'] . '/fckeditor/";
+        </script>' . LB;
+
+        $js .= '<!-- Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it -->
+        <script type="text/javascript">
+            document.getElementById("advanced_editor").style.display=""
+        </script>';     
+        
+        $_SCRIPTS->setJavaScriptFile('advanced_editor', '/javascript/advanced_editor.js');
+        $_SCRIPTS->setJavaScriptFile('storyeditor_fckeditor', '/javascript/storyeditor_fckeditor.js');        
+    }
+    
+    $js .= '<script type="text/javascript">
+    <!-- This code will only be executed by a browser that supports Javascript -->
+    var jstest = ' . $js_showarchivedisabled . ';
+    var jstest2 = ' . $js_showcmtclosedisabled . ';
+    if (jstest) {
+        document.frmstory.expire_month.disabled=true;
+        document.frmstory.expire_day.disabled=true;
+        document.frmstory.expire_year.disabled=true;
+        document.frmstory.expire_hour.disabled=true;
+        document.frmstory.expire_minute.disabled=true;
+        document.frmstory.expire_ampm.disabled=true;
+        document.frmstory.storycode10.disabled=true;
+        document.frmstory.storycode11.disabled=true;
+    }
+    if (jstest2) {
+        document.frmstory.cmt_close_month.disabled=true;
+        document.frmstory.cmt_close_day.disabled=true;
+        document.frmstory.cmt_close_year.disabled=true;
+        document.frmstory.cmt_close_hour.disabled=true;
+        document.frmstory.cmt_close_minute.disabled=true;
+        document.frmstory.cmt_close_ampm.disabled=true;
+    }
+    </script>';    
+    
+    $_SCRIPTS->setJavaScript($js);
+    
+    // *****************************************
+    
     $story_templates->set_var('saved_images', $saved_images);
     $story_templates->set_var('image_form_elements', $fileinputs);
     $story_templates->set_var('lang_hits', $LANG24[18]);
@@ -748,7 +829,6 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $story_templates->set_var('story_id', $story->getSid());
         $story_templates->set_var('old_story_id', $story->EditElements('originalSid'));
     }
-
     $story_templates->set_var('lang_sid', $LANG24[12]);
     $story_templates->set_var('lang_save', $LANG_ADMIN['save']);
     $story_templates->set_var('lang_preview', $LANG_ADMIN['preview']);
