@@ -320,8 +320,7 @@ class database {
     function changeDESCRIBE($sql){
         $sql=trim($sql);
         $testSQL=strtolower($sql);
-        $testSQL=" " . $sql;
-       
+        $testSQL=" " . $testSQL;
         $isIn=strpos($testSQL,'describe ');
         if($isIn>0){
             if($sql[strlen($sql)-1]==';'){
@@ -448,7 +447,7 @@ class database {
             
         } else {
            
-            $result = @mssql_query($sql,$this->_db) or trigger_error($this->dbError($sql) . ' - ' . $sql);
+            $result = @mssql_query($sql,$this->_db) or trigger_error($this->dbError($sql) . ' - ' . $sql, E_USER_ERROR);
             if($result==FALSE){
                 echo "Query Failed: ";
                 echo "<pre>".$this->dbError($sql) . "</pre><hr" . XHTML . ">";
@@ -566,9 +565,7 @@ class database {
         $values=$this->cleanseSQL($values);
         $values=str_replace("'",'"',$values);
         $sql="EXEC doIndexInsert '{$table}', '{$fields}', '{$values}'";
-        //$sql=$this->cleanseSQL($sql);
-//        echo "<pre>" . $sql . "</pre><hr" . XHTML . ">";
-//        exit(0);
+       
         $result=$this->dbQuery($sql,1);
         mssql_free_result($result);
         if ($this->isVerbose()) {
@@ -616,7 +613,7 @@ class database {
                 }
             } else {
                 // error, they both have to be arrays and of the
-                // same size
+                // same size 
                 return false;
             }
         } else {
@@ -935,7 +932,7 @@ class database {
     * @return   array       Returns data array of current row from recordset
     *
     */
-    //here!
+
     function dbFetchArray($recordset, $both = false)
     {
       $this->_numberOfRowsAskedFor["{$recordset}"] = $this->_numberOfRowsAskedFor["{$recordset}"] +1;
@@ -964,7 +961,7 @@ class database {
     * your code should ALWAYS call this function with its resource identifier otherwise you'll just pull off the 
     * last insertted ID which MAY or MAY NOT be the one from YOUR specific insert.  You've been warned!
     */
-    function dbInsertId($link_identifier ='')
+    function dbInsertId($link_identifier ='',$sequence='')
     {
      
        if ($link_identifier ==''){  //wow is this dangerous...  
@@ -1081,91 +1078,26 @@ class database {
        return $string;
        
     }
-  
-    
-    
-    
-    
-    
-    //since nothing can do this properly, i had to write it myself.
-    //trick is that a string csv may have a comma within a delimited csv field which explode
-    //cant handle
-    function parse_csv_sql_string($csv){
-        $len=strlen($csv);
-        $mode=0;        //mode=0 for non string, mode=1 for string
-        $retArray=array();
-        $thisValue='';
-        for($x=0;$x<$len;$x++){
-            //loop thru the string
-            if($csv[$x]=="'"){
-                if($x!=0){
-                    if($csv[$x-1]!="\\"){
-                        //this means that the preceeding char is not escape.. thus this is either the end of a mode 1 or the beginning of a mode 1
-                        if($mode==1){
-                            $mode=0;
-                            //this means that we are done this string value
-                            //dont add this character to the string
-                            }
-                        else{
-                            $mode=1;
-                            //dont add this character to the string....
-                            }
-                        }
-                    else{//this is a character to add.....
-                        $thisValue=$thisValue . $csv[$x];
-                        }
-                    }
-                else{//x==0
-                    $mode=1;
-                    }
-            }//end if csv
-            elseif($csv[$x]==","){
-                if($mode==1){
-                    //this means that the comma falls INSIDE of a string. its a keeper
-                    $thisValue=$thisValue . $csv[$x];
-                    }
-                else{//this is the dilineation between fields.. pop this value
-                    array_push($retArray, $thisValue);
-                    $thisValue='';
-                    $mode=0;
-                    }
-                }//end elseif
-                
-            else{
-                //just add it!
-                $thisValue=$thisValue . $csv[$x];
-                }//end else
-        }//end for
-        array_push($retArray, $thisValue);
-        return $retArray;
-    }//end function  
-    
-    
-    
-    //thanks to php.net for this
-function array_push_associative(&$arr) {
-  $ret = 0;
-  $args = func_get_args();
-  foreach ($args as $arg) {
-      if (is_array($arg)) {
-          foreach ($arg as $key => $value) {
-              @$arr[$key] = $value;
-              $ret++;
-          }
-      }else{
-          @$arr[$arg] = "";
-      }
-  }
-  return $ret;
-} 
- 
-
-
-
-
 
 
+    // thanks to php.net for this
+    function array_push_associative(&$arr)
+    {
+        $ret = 0;
+        $args = func_get_args();
+        foreach ($args as $arg) {
+            if (is_array($arg)) {
+                foreach ($arg as $key => $value) {
+                    @$arr[$key] = $value;
+                    $ret++;
+                }
+            } else {
+                @$arr[$arg] = "";
+            }
+        }
 
+        return $ret;
+    }
 
 
     /**
@@ -1219,6 +1151,15 @@ function array_push_associative(&$arr) {
         }
     }
 
+    /**
+    * @return     string     the version of the database application
+    */
+    function dbGetVersion()
+    {
+        $q = $this->dbQuery("SELECT SERVERPROPERTY('productversion')");
+        $v = $this->dbFetchArray($q, true);
+        return $v[0];
+    }
     
 }//end class
 
